
/*==============================================================================
================================================================================


 Stata Tables and Figures for Mian, Sufi, and Verner 
 Quarterly Journal of Economics, 2017 
 
 
 Out of Sample Tests Done in June 2018
 
================================================================================ 
==============================================================================*/		


cap log close 
clear all 
set more off , permanently
set scheme sol, permanently
graph set window fontface "Times New Roman"


** SET YOUR PATHS HERE
global path "C:\Users\mvarley\Dropbox\MianSufiVarley\QJEUpdateFinal"
cd "${path}"
global destination "C:\Users\mvarley\Dropbox\MianSufiVarley\QJEUpdateFinal"	

/*------------------------------------------------------------------------------

Figure: Scatter Plots
 
------------------------------------------------------------------------------*/

cap est drop *
use "$path/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

drop lnGDP_Fd3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_Fd3 = 100*(ln(F3.rgdp) - ln(rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var lnGDP_Fd3 "$\Delta_3 y_{it+3}$"
lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"

*Main Scatterplots 
lowess lnGDP_Fd3 L1D3HHD_GDP if mainsmp1==1,  nograph generate(lnGDP_Fd3_lowessQJE)
lowess lnGDP_Fd3 L1D3HHD_GDP if mainsmp1~=1,  nograph generate(lnGDP_Fd3_lowessNotQJE)
lowess lnGDP_Fd3 L1D3HHD_GDP ,  nograph generate(lnGDP_Fd3_lowessFull)

reg lnGDP_Fd3 L1D3HHD_GDP if mainsmp1==1
local beta1 = string(_b[L1D3HHD_GDP], "%3.2f")
reg lnGDP_Fd3 L1D3HHD_GDP if mainsmp1~=1
local beta2 = string(_b[L1D3HHD_GDP], "%3.2f")
reg lnGDP_Fd3 L1D3HHD_GDP
local beta3 = string(_b[L1D3HHD_GDP], "%3.2f")


sort L1D3HHD_GDP
# delimit;		
twoway (scatter lnGDP_Fd3 L1D3HHD_GDP if mainsmp1==1 & L1D3HHD_GDP>-10 & L1D3HHD_GDP<30 & lnGDP_Fd3 < 40 & lnGDP_Fd3 > -20 , name(scatterHHDqje,replace)
       m(o) msize(tiny) mc(navy) title("MSV2017 Sample")
	   ytitle("GDP growth, t to t+3" ) xtitle("Household Debt to GDP Expansion, t-4 to t-1") legend(off)) 
	   (scatter lnGDP_Fd3_lowessQJE L1D3HHD_GDP if L1D3HHD_GDP>-10 & L1D3HHD_GDP<30 & mainsmp1==1, legend(off) m(i) connect(l) lw(medthick) lpattern(solid) lcolor(navy)),
	   text(35 25 "{&beta}= `beta1'", place(e) size(medium) color(navy));    
graph export "$destination/Fig_scatter_HHDQJE.png", replace;

# delimit;		
twoway (scatter lnGDP_Fd3 L1D3HHD_GDP if mainsmp1~=1 & L1D3HHD_GDP>-10 & L1D3HHD_GDP<30 & lnGDP_Fd3 < 40 & lnGDP_Fd3 > -20 , name(scatterHHDnotqje,replace)
       m(o) msize(tiny) mc(maroon) title("IMF2018 Sample")
	   ytitle("GDP growth, t to t+3" ) xtitle("Household Debt to GDP Expansion, t-4 to t-1") legend(off)) 
	   (scatter lnGDP_Fd3_lowessNotQJE L1D3HHD_GDP if L1D3HHD_GDP>-10 & L1D3HHD_GDP<30 & mainsmp1~=1, legend(off) m(i) connect(l) lw(medthick) lpattern(solid) lcolor(maroon)),
	   text(35 25 "{&beta}= `beta2'", place(e) size(medium) color(maroon));    
graph export "$destination/Fig_scatter_HHDNotQJE.png", replace;

# delimit;		
twoway (scatter lnGDP_Fd3 L1D3HHD_GDP if L1D3HHD_GDP>-10 & L1D3HHD_GDP<30 & lnGDP_Fd3 < 40 & lnGDP_Fd3 > -20 , name(scatterHHDfull,replace)
       m(o) msize(tiny) mc(black) title("Full Sample")
	   ytitle("GDP growth, t to t+3" ) xtitle("Household Debt to GDP Expansion, t-4 to t-1") legend(off)) 
	   (scatter lnGDP_Fd3_lowessFull L1D3HHD_GDP if L1D3HHD_GDP>-10 & L1D3HHD_GDP<30, legend(off) m(i) connect(l) lw(medthick) lpattern(solid) lcolor(black)),
	   text(35 25 "{&beta}= `beta3'", place(e) size(medium) color(black));     
graph export "$destination/Fig_scatter_HHDFull.png", replace;

/*------------------------------------------------------------------------------

 Table: Coverage Difference
 
------------------------------------------------------------------------------*/
	
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

reg lnGDP_Fd3  L1D3HHD_GDP L1D3NFD_GDP  if mainsmp1==1
gen regsample = e(sample)
tempfile  main_data
save     `main_data' 

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d12  = 100*(ln(rgdp) - ln(L.rgdp))
gen lnGDP2  = 100*(ln(rgdp))
gen D1HHD_GDP2 = hh_ls - L.hh_ls
gen D1NFD_GDP2 = nfc_ls - L.nfc_ls

sort country year
		
levelsof country, local(cs)

matrix drop _all
matrix W = J(190, 4, 0)

local r=1
foreach c in `cs' {
	local rown = "`rown' `c'"
	summ year if country=="`c'" & hh_ls < . & nfc_ls < . & lnGDP2<.	
	matrix W[`r',1] = r(min)
	matrix W[`r',2] = r(max)
	
	summ year if country=="`c'" & mainsmp1==1	
	matrix W[`r',3] = r(min)
	matrix W[`r',4] = r(max)
	
	local r = `r'+1
	
}

matrix list W

egen ctag = tag(country)
keep if ctag==1
keep country
gen t = _n
tempfile row
save `row', replace

clear
svmat2 W

gen t=_n
merge 1:1 t using `row', nogen

tostring W1 W2 W3 W4, replace
gen new_sample = W1+"-"+W2
gen old_sample = W3+"-"+W4
replace old_sample = "NA" if old_sample == ".-."
order country new_sample old_sample
keep country new_sample old_sample
compress country

lab var country "Country"
lab var new_sample "GDD 2018"
lab var old_sample "MSV 2017"

replace country = "Trinidad and Tobago" if country=="Trinidad & Tobago"
drop if new_sample == ".-."

tempfile MAIN
save `MAIN', replace

* QJE Table

use `MAIN', clear
keep if old_sample ~="NA"

texsave using "$path\TableCoverageQJE.tex", /*
	   */ nofix location(h) align(l|c|c) width(8cm) /*
	   */ replace frag varlabels title("Sample Coverage of IMF Global Debt Database and \cite{miansufiverner2017}" \label{tab:TableCoverageQJE})

* New Countries Table

local nn = 1
forvalues yy = 1(36)73 {
use `MAIN', clear
keep if old_sample =="NA"
drop old_sample
rename country country`nn'
rename new_sample new_sample`nn'
lab var country`nn' "Country"
lab var new_sample`nn' "Coverage"
keep if _n >= `yy' & _n < `yy'+36
gen t=_n
tempfile NOTQJE`nn'
save `NOTQJE`nn'', replace
local nn = `nn'+1
}

use `NOTQJE1', clear

merge 1:1 t using `NOTQJE2', nogen
merge 1:1 t using `NOTQJE3', nogen
drop t

replace country3 = "Venezuela" if country3 == "Venezuela, Republica Bolivariana de"
replace country3 = "Sao Tome and Principe" if country3 == "São Tomé and Príncipe"
replace country3 = "St. Vincent" if country3 == "St. Vincent and the Grenadines"

texsave using "$path\TableCoverageNotQJE.tex", /*
	   */ nofix location(htbp) align(l|c|l|c|l|c) width(18.5cm) /*
	   */ replace frag varlabels title("Sample Coverage of IMF's Global Debt Database: 105 New Countries" \label{tab:TableCoverageNotQJE})



/*------------------------------------------------------------------------------

 Table: Summary Statistics
 
------------------------------------------------------------------------------*/
		
*****************************
*Full Sample
*****************************		
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"


reg lnGDP_Fd3  L1D3HHD_GDP L1D3NFD_GDP  if mainsmp1==1
gen regsample = e(sample)
tempfile  main_data
save     `main_data' 

drop lnGDP_d1 lnGDP_Fd3 D1PD_GDP D3PD_GDP D1HHD_GDP D3HHD_GDP D1NFD_GDP D3NFD_GDP L1D3GD_GDP_Sol2

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1  = 100*(ln(rgdp) - ln(L.rgdp))
gen lnGDP_Fd3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen D1PD_GDP  = pvd_ls - L.pvd_ls
gen D3PD_GDP  = pvd_ls - L3.pvd_ls
gen D1HHD_GDP = hh_ls - L.hh_ls
gen D3HHD_GDP = hh_ls - L3.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
gen D3NFD_GDP = nfc_ls - L3.nfc_ls
gen L1D3GD_GDP_Sol2 = cg - L3.cg

keep if D3HHD_GDP < . & D3NFD_GDP < .
		
local dvars "lnGDP_Fd3 D3PD_GDP D3HHD_GDP D3NFD_GDP  L1D3GD_GDP_Sol2"

*** (i) Nobs, Mean, Median, SD, SD/SD_y

estpost summarize `dvars', detail

matrix S= [e(count)\e(mean)\e(p50)\e(sd)]'
matrix list S
clear
* Store in new dataset
svmat2 S, rnames(variable)
rename S1 Nobs
rename S2 Mean
rename S3 Median
rename S4 SD 
sum SD if variable=="lnGDP_Fd3"
gen SD_SDy = SD/r(mean)
order variable Nobs Mean Median SD SD_SDy
gen sercorr = .
tempfile d1_sumstats
save    `d1_sumstats'


*** (ii) Serial Corr 

** compute serial corr for each country, then take average weighted by sample size 
use `main_data', clear

drop if c_mainsmp~=1

levelsof country, local(countries)

foreach v in `dvars'{

	* temporary dataset: variable `v' serial correlation for each country
	use `main_data', clear
	collapse year, by(country)
	drop year
	tempfile temp`v'
	gen sercorr     = .
	gen T           = .
	save    `temp`v''

	* compute serial corr for variable v across all countries in main reg and take avg
	foreach i in `countries' {
		use `main_data', clear
		keep if country == "`i'" /* & if regsample==1*/
		tsset year, yearly
		cap qui corrgram `v', lags(1)        // compute autocorrelation for `v' for country `i'
		scalar rac1 = r(ac1)
		qui sum `v'
		scalar nobs = r(N)
		use `temp`v'', clear        
		replace sercorr = rac1 if country == "`i'"
		replace       T = nobs if country == "`i'"
		save `temp`v'', replace		
	}
	list
	sum T
	display "Number of total country-years= " r(sum) // should be ~695
	* take weighted average (by sample size) and store in summary stats dataset hp_sumstats
	summarize sercorr [aw=T]
	scalar meansercorr = r(mean)
	use `d1_sumstats', clear
	replace sercorr = meansercorr if variable=="`v'"
	save `d1_sumstats', replace
}



*** Make Table 

* column headers
label var Nobs "N"
label var Mean "Mean"
label var Median "Median"
label var SD   "SD"
label var SD_SDy "\( \frac{SD}{SD( \Delta_3 y )} \) "
label var sercorr "Ser. Cor."

* variable names (first column)
replace variable = " \( \Delta y \) " if variable=="lnGDP_d1"
replace variable = " \( \Delta_3 y \) " if variable=="lnGDP_Fd3"
replace variable = " \( \Delta d^{Private} \) " if variable=="D1PD_GDP"
replace variable = " \( \Delta_3 d^{Private} \) " if variable=="D3PD_GDP"
replace variable = " \( \Delta d^{HH} \) " if variable=="D1HHD_GDP"
replace variable = " \( \Delta_3 d^{HH} \) " if variable=="D3HHD_GDP"
replace variable = " \( \Delta d^{F} \) " if variable=="D1NFD_GDP"
replace variable = " \( \Delta_3 d^{F} \) " if variable=="D3NFD_GDP"
replace variable = "\( \Delta_3 d^{Gov} \)" if variable=="L1D3GD_GDP_Sol2"
replace variable = "\( \Delta_3 d^{Netforeign} \)" if variable=="L1D3NFL_GDP"
replace variable = " \( \Delta c \) " if variable=="lnhhC_realLCU_d1"
replace variable = " \( \Delta c^{dur} \) " if variable=="lnhhCdur_realLCU_Fd1"
replace variable = " \( \Delta c^{nondur} \) " if variable=="lnhhCnondur_realLCU_Fd1"
replace variable = " \( \Delta C/Y \) " if variable=="hhC_GDP_d1"
replace variable = " \( \Delta i \) " if variable=="lnI_realLCU_d1"
replace variable = " \( \Delta g \) " if variable=="lnGC_realLCU_d1"
replace variable = " \( \Delta x \) " if variable=="lnX_ifs_d1"
replace variable = " \( \Delta m \) " if variable=="lnIm_ifs_d1"
replace variable = " \( \Delta NX/Y \) " if variable=="NX_ifs_GDP_d1"
replace variable = " \( \Delta CA/Y \) " if variable=="CA_GDP_d1"
replace variable = " \( \Delta s^{XC} \)" if variable=="s_Xc_d1"
replace variable = " \( \Delta s^{MC} \)" if variable=="s_Imc_d1"
replace variable = " \( \Delta reer \)" if variable=="D1lnREER_BIS_m12"
replace variable = " \( \Delta u \)" if variable=="unrate_Fd1"
replace variable = " \( \Delta_3 u \)" if variable=="unrate_Fd3"
replace variable = "\( \Delta_3 y_{t+3|t}^{WEO} \)" if variable=="Fd3_lnGDP_WEO_F"
replace variable = "\( \Delta_3 (y_{t+3} - y_{t+3|t}^{WEO}) \)" if variable=="Fd3_WEOerror_F"
replace variable = "\( \Delta_3 \ln(P^{Housing}) \)" if variable=="L1D3lnRHPIq4"
replace variable = " \( spr^{real} \)" if variable=="spr_r_q4"
replace variable = " \( spr^{MS} \)" if variable=="ih_ig10"
replace variable = " \( spr^{CS} \)" if variable=="ic_ig10"
replace variable = " \( spr^{corp} \)" if variable=="icorp_ig10"
replace variable = "Avg HYS, t-3 to t-1" if variable=="L1toL3hys"


* round
foreach v in Mean Median SD SD_SDy sercorr {
	replace `v' = round(`v',0.01)
	format  `v' %9.2f	

}

drop if variable== "Avg HYS, t-3 to t-1"
drop if variable== " \( spr^{CS} \)"

******************* FIGURE OUT *********************
textdoc do "${destination}/Table_SumStats_d12"
texdoc init "${destination}/Table_SumStats_d12", replace
tex &N&Mean&Median&SD&\( \frac{SD}{SD( \Delta_3 y )} \) &Ser. Cor. \tabularnewline
texdoc close

#delimit ;
texsave using "${destination}/Table_SumStats_d1.tex", 
        nofix location(h) marker(Table_SumStats_d1)
        replace frag varlabels title("Summary Statistics");
#delimit cr

#delimit ;
dataout, save("${destination}/Table_SumStats_d12") 
        tex replace;
#delimit cr

*****************************
*QJE Sample
*****************************	
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"


reg lnGDP_Fd3  L1D3HHD_GDP L1D3NFD_GDP  if mainsmp1==1
gen regsample = e(sample)
tempfile  main_data
save     `main_data' 

drop lnGDP_d1 lnGDP_Fd3 D1PD_GDP D3PD_GDP D1HHD_GDP D3HHD_GDP D1NFD_GDP D3NFD_GDP L1D3GD_GDP_Sol2

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1  = 100*(ln(rgdp) - ln(L.rgdp))
gen lnGDP_Fd3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen D1PD_GDP  = pvd_ls - L.pvd_ls
gen D3PD_GDP  = pvd_ls - L3.pvd_ls
gen D1HHD_GDP = hh_ls - L.hh_ls
gen D3HHD_GDP = hh_ls - L3.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
gen D3NFD_GDP = nfc_ls - L3.nfc_ls
gen L1D3GD_GDP_Sol2 = cg - L3.cg

keep if D3HHD_GDP < . & D3NFD_GDP < .
		
local dvars "lnGDP_Fd3 D3PD_GDP D3HHD_GDP D3NFD_GDP  L1D3GD_GDP_Sol2"

*** (i) Nobs, Mean, Median, SD, SD/SD_y

estpost summarize `dvars' if regsample==1, detail

matrix S= [e(count)\e(mean)\e(p50)\e(sd)]'
matrix list S
clear
* Store in new dataset
svmat2 S, rnames(variable)
rename S1 Nobs
rename S2 Mean
rename S3 Median
rename S4 SD 
sum SD if variable=="lnGDP_Fd3"
gen SD_SDy = SD/r(mean)
order variable Nobs Mean Median SD SD_SDy
gen sercorr = .
tempfile d1_sumstats
save    `d1_sumstats'


*** (ii) Serial Corr 

** compute serial corr for each country, then take average weighted by sample size 
use `main_data', clear

drop if c_mainsmp~=1

levelsof country, local(countries)

foreach v in `dvars'{

	* temporary dataset: variable `v' serial correlation for each country
	use `main_data', clear
	collapse year, by(country)
	drop year
	tempfile temp`v'
	gen sercorr     = .
	gen T           = .
	save    `temp`v''

	* compute serial corr for variable v across all countries in main reg and take avg
	foreach i in `countries' {
		use `main_data', clear
		keep if country == "`i'" & regsample==1
		tsset year, yearly
		cap qui corrgram `v', lags(1)        // compute autocorrelation for `v' for country `i'
		scalar rac1 = r(ac1)
		qui sum `v'
		scalar nobs = r(N)
		use `temp`v'', clear        
		replace sercorr = rac1 if country == "`i'"
		replace       T = nobs if country == "`i'"
		save `temp`v'', replace		
	}
	list
	sum T
	display "Number of total country-years= " r(sum) // should be ~695
	* take weighted average (by sample size) and store in summary stats dataset hp_sumstats
	summarize sercorr [aw=T]
	scalar meansercorr = r(mean)
	use `d1_sumstats', clear
	replace sercorr = meansercorr if variable=="`v'"
	save `d1_sumstats', replace
}



*** Make Table 

* column headers
label var Nobs "N"
label var Mean "Mean"
label var Median "Median"
label var SD   "SD"
label var SD_SDy "\( \frac{SD}{SD( \Delta_3 y )} \) "
label var sercorr "Ser. Cor."

* variable names (first column)
replace variable = " \( \Delta y \) " if variable=="lnGDP_d1"
replace variable = " \( \Delta_3 y \) " if variable=="lnGDP_Fd3"
replace variable = " \( \Delta d^{Private} \) " if variable=="D1PD_GDP"
replace variable = " \( \Delta_3 d^{Private} \) " if variable=="D3PD_GDP"
replace variable = " \( \Delta d^{HH} \) " if variable=="D1HHD_GDP"
replace variable = " \( \Delta_3 d^{HH} \) " if variable=="D3HHD_GDP"
replace variable = " \( \Delta d^{F} \) " if variable=="D1NFD_GDP"
replace variable = " \( \Delta_3 d^{F} \) " if variable=="D3NFD_GDP"
replace variable = "\( \Delta_3 d^{Gov} \)" if variable=="L1D3GD_GDP_Sol2"
replace variable = "\( \Delta_3 d^{Netforeign} \)" if variable=="L1D3NFL_GDP"
replace variable = " \( \Delta c \) " if variable=="lnhhC_realLCU_d1"
replace variable = " \( \Delta c^{dur} \) " if variable=="lnhhCdur_realLCU_Fd1"
replace variable = " \( \Delta c^{nondur} \) " if variable=="lnhhCnondur_realLCU_Fd1"
replace variable = " \( \Delta C/Y \) " if variable=="hhC_GDP_d1"
replace variable = " \( \Delta i \) " if variable=="lnI_realLCU_d1"
replace variable = " \( \Delta g \) " if variable=="lnGC_realLCU_d1"
replace variable = " \( \Delta x \) " if variable=="lnX_ifs_d1"
replace variable = " \( \Delta m \) " if variable=="lnIm_ifs_d1"
replace variable = " \( \Delta NX/Y \) " if variable=="NX_ifs_GDP_d1"
replace variable = " \( \Delta CA/Y \) " if variable=="CA_GDP_d1"
replace variable = " \( \Delta s^{XC} \)" if variable=="s_Xc_d1"
replace variable = " \( \Delta s^{MC} \)" if variable=="s_Imc_d1"
replace variable = " \( \Delta reer \)" if variable=="D1lnREER_BIS_m12"
replace variable = " \( \Delta u \)" if variable=="unrate_Fd1"
replace variable = " \( \Delta_3 u \)" if variable=="unrate_Fd3"
replace variable = "\( \Delta_3 y_{t+3|t}^{WEO} \)" if variable=="Fd3_lnGDP_WEO_F"
replace variable = "\( \Delta_3 (y_{t+3} - y_{t+3|t}^{WEO}) \)" if variable=="Fd3_WEOerror_F"
replace variable = "\( \Delta_3 \ln(P^{Housing}) \)" if variable=="L1D3lnRHPIq4"
replace variable = " \( spr^{real} \)" if variable=="spr_r_q4"
replace variable = " \( spr^{MS} \)" if variable=="ih_ig10"
replace variable = " \( spr^{CS} \)" if variable=="ic_ig10"
replace variable = " \( spr^{corp} \)" if variable=="icorp_ig10"
replace variable = "Avg HYS, t-3 to t-1" if variable=="L1toL3hys"


* round
foreach v in Mean Median SD SD_SDy sercorr {
	replace `v' = round(`v',0.01)
	format  `v' %9.2f	

}

drop if variable== "Avg HYS, t-3 to t-1"
drop if variable== " \( spr^{CS} \)"

#delimit ;
texsave using "${destination}/Table_SumStats_d1QJE.tex", 
        nofix location(h) marker(Table_SumStats_d1QJE)
        replace frag varlabels title("Summary Statistics");
#delimit cr

*****************************
*Not QJE Sample
*****************************	
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"


reg lnGDP_Fd3  L1D3HHD_GDP L1D3NFD_GDP  if mainsmp1==1
gen regsample = e(sample)
tempfile  main_data
save     `main_data' 

egen csample = mean(mainsmp1), by(country)
keep if csample==.

drop lnGDP_d1 lnGDP_Fd3 D1PD_GDP D3PD_GDP D1HHD_GDP D3HHD_GDP D1NFD_GDP D3NFD_GDP L1D3GD_GDP_Sol2

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1  = 100*(ln(rgdp) - ln(L.rgdp))
gen lnGDP_Fd3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen D1PD_GDP  = pvd_ls - L.pvd_ls
gen D3PD_GDP  = pvd_ls - L3.pvd_ls
gen D1HHD_GDP = hh_ls - L.hh_ls
gen D3HHD_GDP = hh_ls - L3.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
gen D3NFD_GDP = nfc_ls - L3.nfc_ls
gen L1D3GD_GDP_Sol2 = cg - L3.cg

keep if D3HHD_GDP < . & D3NFD_GDP < .
		
local dvars "lnGDP_Fd3 D3PD_GDP D3HHD_GDP D3NFD_GDP  L1D3GD_GDP_Sol2"

*** (i) Nobs, Mean, Median, SD, SD/SD_y

estpost summarize `dvars' /*if regsample==1*/, detail

matrix S= [e(count)\e(mean)\e(p50)\e(sd)]'
matrix list S
clear
* Store in new dataset
svmat2 S, rnames(variable)
rename S1 Nobs
rename S2 Mean
rename S3 Median
rename S4 SD 
sum SD if variable=="lnGDP_Fd3"
gen SD_SDy = SD/r(mean)
order variable Nobs Mean Median SD SD_SDy
gen sercorr = .
tempfile d1_sumstats
save    `d1_sumstats'


*** (ii) Serial Corr 

** compute serial corr for each country, then take average weighted by sample size 
use `main_data', clear

drop if c_mainsmp~=1

levelsof country, local(countries)

foreach v in `dvars'{

	* temporary dataset: variable `v' serial correlation for each country
	use `main_data', clear
	collapse year, by(country)
	drop year
	tempfile temp`v'
	gen sercorr     = .
	gen T           = .
	save    `temp`v''

	* compute serial corr for variable v across all countries in main reg and take avg
	foreach i in `countries' {
		use `main_data', clear
		keep if country == "`i'" /* & if regsample==1*/
		tsset year, yearly
		cap qui corrgram `v', lags(1)        // compute autocorrelation for `v' for country `i'
		scalar rac1 = r(ac1)
		qui sum `v'
		scalar nobs = r(N)
		use `temp`v'', clear        
		replace sercorr = rac1 if country == "`i'"
		replace       T = nobs if country == "`i'"
		save `temp`v'', replace		
	}
	list
	sum T
	display "Number of total country-years= " r(sum) // should be ~695
	* take weighted average (by sample size) and store in summary stats dataset hp_sumstats
	summarize sercorr [aw=T]
	scalar meansercorr = r(mean)
	use `d1_sumstats', clear
	replace sercorr = meansercorr if variable=="`v'"
	save `d1_sumstats', replace
}



*** Make Table 

* column headers
label var Nobs "N"
label var Mean "Mean"
label var Median "Median"
label var SD   "SD"
label var SD_SDy "\( \frac{SD}{SD( \Delta_3 y )} \) "
label var sercorr "Ser. Cor."

* variable names (first column)
replace variable = " \( \Delta y \) " if variable=="lnGDP_d1"
replace variable = " \( \Delta_3 y \) " if variable=="lnGDP_Fd3"
replace variable = " \( \Delta d^{Private} \) " if variable=="D1PD_GDP"
replace variable = " \( \Delta_3 d^{Private} \) " if variable=="D3PD_GDP"
replace variable = " \( \Delta d^{HH} \) " if variable=="D1HHD_GDP"
replace variable = " \( \Delta_3 d^{HH} \) " if variable=="D3HHD_GDP"
replace variable = " \( \Delta d^{F} \) " if variable=="D1NFD_GDP"
replace variable = " \( \Delta_3 d^{F} \) " if variable=="D3NFD_GDP"
replace variable = "\( \Delta_3 d^{Gov} \)" if variable=="L1D3GD_GDP_Sol2"
replace variable = "\( \Delta_3 d^{Netforeign} \)" if variable=="L1D3NFL_GDP"
replace variable = " \( \Delta c \) " if variable=="lnhhC_realLCU_d1"
replace variable = " \( \Delta c^{dur} \) " if variable=="lnhhCdur_realLCU_Fd1"
replace variable = " \( \Delta c^{nondur} \) " if variable=="lnhhCnondur_realLCU_Fd1"
replace variable = " \( \Delta C/Y \) " if variable=="hhC_GDP_d1"
replace variable = " \( \Delta i \) " if variable=="lnI_realLCU_d1"
replace variable = " \( \Delta g \) " if variable=="lnGC_realLCU_d1"
replace variable = " \( \Delta x \) " if variable=="lnX_ifs_d1"
replace variable = " \( \Delta m \) " if variable=="lnIm_ifs_d1"
replace variable = " \( \Delta NX/Y \) " if variable=="NX_ifs_GDP_d1"
replace variable = " \( \Delta CA/Y \) " if variable=="CA_GDP_d1"
replace variable = " \( \Delta s^{XC} \)" if variable=="s_Xc_d1"
replace variable = " \( \Delta s^{MC} \)" if variable=="s_Imc_d1"
replace variable = " \( \Delta reer \)" if variable=="D1lnREER_BIS_m12"
replace variable = " \( \Delta u \)" if variable=="unrate_Fd1"
replace variable = " \( \Delta_3 u \)" if variable=="unrate_Fd3"
replace variable = "\( \Delta_3 y_{t+3|t}^{WEO} \)" if variable=="Fd3_lnGDP_WEO_F"
replace variable = "\( \Delta_3 (y_{t+3} - y_{t+3|t}^{WEO}) \)" if variable=="Fd3_WEOerror_F"
replace variable = "\( \Delta_3 \ln(P^{Housing}) \)" if variable=="L1D3lnRHPIq4"
replace variable = " \( spr^{real} \)" if variable=="spr_r_q4"
replace variable = " \( spr^{MS} \)" if variable=="ih_ig10"
replace variable = " \( spr^{CS} \)" if variable=="ic_ig10"
replace variable = " \( spr^{corp} \)" if variable=="icorp_ig10"
replace variable = "Avg HYS, t-3 to t-1" if variable=="L1toL3hys"


* round
foreach v in Mean Median SD SD_SDy sercorr {
	replace `v' = round(`v',0.01)
	format  `v' %9.2f	

}

drop if variable== "Avg HYS, t-3 to t-1"
drop if variable== " \( spr^{CS} \)"

#delimit ;
texsave using "${destination}/Table_SumStats_d1NotQJE.tex", 
        nofix location(h) marker(Table_SumStats_d1NotQJE)
        replace frag varlabels title("Summary Statistics");
#delimit cr


/*------------------------------------------------------------------------------

 Table 2: Timing of RHS
 
------------------------------------------------------------------------------*/

*****************************
*Full Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

egen cgroup = group(country)

xtset cgroup year, y 

drop lnGDP_d3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP


gen lnGDP_d3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"

gen L1yd3 = L.lnGDP_d3
 
forv i=0/6 {
	gen F`i'L1yd3 = F`i'.L1yd3
	local j=`i'-1
	label var F`i'L1yd3 "$ \Delta_3 y_{it+`j'} $"
}
	label var F1L1yd3 "$ \Delta_3 y_{it} $"
	label var F0L1yd3 "$ \Delta_3 y_{it-1} $"

forv i=0/6 {	
	eststo: xtivreg2 F`i'L1yd3 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)
}
 
local controls ""

* Table: Varying timing of lag
#delimit ;
esttab  using "${destination}/Table_timing.tex",       
	   keep(L1D3HHD_GDP L1D3NFD_GDP) style(tex)
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant 
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+k}, k=-1,0,...,5  \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast label frag
	   booktabs   substitute(\_ _) nonotes nonum 
	   scalars("r2 \(R^2\)") ;
#delimit cr

 
*****************************
*QJE Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

egen cgroup = group(country)

xtset cgroup year, y 

drop lnGDP_d3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP


gen lnGDP_d3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"

gen L1yd3 = L.lnGDP_d3
 
forv i=0/6 {
	gen F`i'L1yd3 = F`i'.L1yd3
	local j=`i'-1
	label var F`i'L1yd3 "$ \Delta_3 y_{it+`j'} $"
}
	label var F1L1yd3 "$ \Delta_3 y_{it} $"
	label var F0L1yd3 "$ \Delta_3 y_{it-1} $"

forv i=0/6 {	
	eststo: xtivreg2 F`i'L1yd3 L1D3HHD_GDP L1D3NFD_GDP  if c_mainsmp==1 , fe cluster(cgroup year)
}
 
local controls ""

* Table: Varying timing of lag
#delimit ;
esttab  using "${destination}/Table_timingQJE.tex",       
	   keep(L1D3HHD_GDP L1D3NFD_GDP)  style(tex)
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant 
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+k}, k=-1,0,...,5  \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast label frag
	   booktabs   substitute(\_ _) nonotes
	   scalars("r2 \(R^2\)") ;
#delimit cr

*****************************
*Not QJE Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

egen csample = mean(mainsmp1), by(country)
keep if csample==.

egen cgroup = group(country)

xtset cgroup year, y 

drop lnGDP_d3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP


gen lnGDP_d3 = 100*(ln(rgdp) - ln(L3.rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"

gen L1yd3 = L.lnGDP_d3
 
forv i=0/6 {
	gen F`i'L1yd3 = F`i'.L1yd3
	local j=`i'-1
	label var F`i'L1yd3 "$ \Delta_3 y_{it+`j'} $"
}
	label var F1L1yd3 "$ \Delta_3 y_{it} $"
	label var F0L1yd3 "$ \Delta_3 y_{it-1} $"

forv i=0/6 {	
	eststo: xtivreg2 F`i'L1yd3 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)	
}
 
local controls ""

* Table: Varying timing of lag
#delimit ;
esttab  using "${destination}/Table_timingNotQJE.tex",       
	   keep(L1D3HHD_GDP L1D3NFD_GDP) 
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant 
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+k}, k=-1,0,...,5  \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast label frag
	   booktabs   substitute(\_ _) nonotes
	   scalars("r2 \(R^2\)") ;
#delimit cr


/*------------------------------------------------------------------------------

 Table 3: Household Debt Expansion Predicts Lower Growth
 
------------------------------------------------------------------------------*/


*****************************
*Full Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

drop lnGDP_d1 lnGDP_Fd3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1 = 100*(ln(rgdp) - ln(L3.rgdp))
gen lnGDP_Fd3 = 100*(ln(F3.rgdp) - ln(rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var lnGDP_Fd3 "$\Delta_3 y_{it+3}$"
lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"


* (1) Total private debt
eststo: xtivreg2 lnGDP_Fd3 L1D3PD_GDP if L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (2) HHD
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP if L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (3) NFD	
eststo: xtivreg2 lnGDP_Fd3 L1D3NFD_GDP if L1D3NFD_GDP~=., fe cluster(cgroup year)

* (4) HHD and NFD together
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)

drop L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1

gen L1lnGDP_d1 = L1.lnGDP_d1
gen L2lnGDP_d1 = L2.lnGDP_d1
gen L3lnGDP_d1 = L3.lnGDP_d1

eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)

* (6) GovDebt/GDP
eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2, fe cluster(cgroup year)



#delimit ;
esttab using "${destination}/Table3.tex", 
	   keep(L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2) 
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant nomtitles
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+3} \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast  scalars("r2 \(R^2\)")  frag
	   booktabs label  nonotes substitute(\_ _);
#delimit cr	   


*****************************
*QJE Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

drop lnGDP_d1 lnGDP_Fd3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1 = 100*(ln(rgdp) - ln(L3.rgdp))
gen lnGDP_Fd3 = 100*(ln(F3.rgdp) - ln(rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var lnGDP_Fd3 "$\Delta_3 y_{it+3}$"
lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"


* (1) Total private debt
eststo: xtivreg2 lnGDP_Fd3 L1D3PD_GDP if mainsmp1==1 & L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (2) HHD
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP if mainsmp1==1 & L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (3) NFD	
eststo: xtivreg2 lnGDP_Fd3 L1D3NFD_GDP if mainsmp1==1 & L1D3NFD_GDP~=., fe cluster(cgroup year)

* (4) HHD and NFD together
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP L1D3NFD_GDP if mainsmp1==1, fe cluster(cgroup year)

drop L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1

gen L1lnGDP_d1 = L1.lnGDP_d1
gen L2lnGDP_d1 = L2.lnGDP_d1
gen L3lnGDP_d1 = L3.lnGDP_d1

eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP if mainsmp1==1, fe cluster(cgroup year)

* (6) GovDebt/GDP
eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 if mainsmp1==1, fe cluster(cgroup year)

#delimit ;
esttab using "${destination}/Table3QJE.tex", 
	   keep(L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2) 
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant nomtitles
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+3} \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast  scalars("r2 \(R^2\)") frag
	   booktabs label  nonotes substitute(\_ _);
#delimit cr	   


*****************************
*Not QJE Sample
*****************************
cap est drop *
use "${path}/masterdata_annual.dta", clear

rename c country
replace country = "Hong Kong SAR" if country == "Hong Kong"
replace country = "Korea, Republic of" if country == "Korea, Rep."

merge 1:1 country year using "$path\GlobalDebtDatabase_v043018merge"

egen csample = mean(mainsmp1), by(country)
keep if csample==.

drop lnGDP_d1 lnGDP_Fd3 L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2 D1HHD_GDP D1NFD_GDP

egen cgroup = group(country)
xtset cgroup year, y

gen lnGDP_d1 = 100*(ln(rgdp) - ln(L3.rgdp))
gen lnGDP_Fd3 = 100*(ln(F3.rgdp) - ln(rgdp))
gen L1D3PD_GDP  = L.pvd_ls - L4.pvd_ls
gen L1D3HHD_GDP = L.hh_ls - L4.hh_ls
gen L1D3NFD_GDP = L.nfc_ls - L4.nfc_ls
gen L1D3GD_GDP_Sol2 = L.cg - L4.cg

gen D1HHD_GDP = hh_ls - L.hh_ls
gen D1NFD_GDP = nfc_ls - L.nfc_ls
keep if D1HHD_GDP < . & D1NFD_GDP < .

lab var lnGDP_Fd3 "$\Delta_3 y_{it+3}$"
lab var L1D3PD_GDP "$\Delta_3 d^{Private}_{it-1}$"
lab var L1D3HHD_GDP "$\Delta_3 d^{HH}_{it-1}$"
lab var L1D3NFD_GDP "$\Delta_3 d^{F}_{it-1}$"
lab var L1D3GD_GDP_Sol2 "\( \Delta_3 d^{Gov}_{it-1} \)"


* (1) Total private debt
eststo: xtivreg2 lnGDP_Fd3 L1D3PD_GDP if L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (2) HHD
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP if L1D3NFD_GDP~=. , fe cluster(cgroup year)

* (3) NFD	
eststo: xtivreg2 lnGDP_Fd3 L1D3NFD_GDP if L1D3NFD_GDP~=., fe cluster(cgroup year)

* (4) HHD and NFD together
eststo: xtivreg2 lnGDP_Fd3 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)

drop L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1

gen L1lnGDP_d1 = L1.lnGDP_d1
gen L2lnGDP_d1 = L2.lnGDP_d1
gen L3lnGDP_d1 = L3.lnGDP_d1

eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP, fe cluster(cgroup year)

* (6) GovDebt/GDP
eststo: xtivreg2 lnGDP_Fd3 L1lnGDP_d1 L2lnGDP_d1 L3lnGDP_d1 L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2, fe cluster(cgroup year)

#delimit ;
esttab using "${destination}/Table3NotQJE.tex", 
	   keep(L1D3PD_GDP L1D3HHD_GDP L1D3NFD_GDP L1D3GD_GDP_Sol2) 
	   replace compress b(a3) se(a3)  star(+ 0.10 * 0.05 ** 0.01 ) noconstant nomtitles
	   mgroups( "Dependent variable: \( \Delta_3 y_{it+3} \)" , pattern(1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  
	   obslast  scalars("r2 \(R^2\)") frag
	   booktabs label  nonotes substitute(\_ _);
#delimit cr	   

